---
test_data: TD_76_09_29_31
test_title: overlapped arg vals from diff arg types
---

Case: two different `arg_type`-s with some of their `arg_value`-s matching as stings.

For example, in `ServiceArgType`, imagine value `amer.us` is both:
*   `GeoRegion`
*   `HostName`

If such `ArgType`-s used in a query for an object, it is important not
to consume the same token by more than one `ArgType`.
